/*!
INameInterface.h
 Menu Disc Demo
 
 Author: Jeroen Verbeek
 Copyright (c) Jeroen Verbeek, 2003-2004. All rights reserved.
 
 This software is provided without any guarantee.
 No responsibility taken for any problems caused by the use if this software.
 
 Anyone is authorised to use this program code and methods without warranty,
 all that is required is that you contact me (jeroen@happymakinggames.com),
 and tell me that you use it and what you use it in -
 all I want is to know is who uses it and where.
 
 I will not ask for payment in any way: this code is free.
 If you encounter a bug with the code, please tell me about it.
 If you have a bug-fix for the code please provide me with it.
 If you think of an improvement please tell me about it.
 You are not required to provide me with bug reports, bug fixes or improvements.
 If you require me to perform any work related to this code or
 not related to this code, please contact me: I am always open to offers.
 
 Pie menus are in no way my original idea, I stumbled on the idea a few years ago,
 specifically Don Hopkins' http://catalog.com/hopkins/piemenus/piemenus-hopkins.html.
 I am a big fan of circular menus (disc menus).
 I am of the opinion that they provide the quickest method of selecting an action
 from a structured tree of actions. A menu of actions organised following this method
 will, in time, allow almost "blind selection" of actions. Each action selection
 requires the same distance of mouse movement, just in a slightly diferent angle.
 In my opinion this seems to work best with menu discs of no more than 8 items.
 There is plenty of research to be found through the internet regarding the 
 advantages of circular menus, for example: muscle memory.
 Some websites I recommend you look at are:
 
 http://catalog.com/hopkins/piemenus/piemenus-hopkins.html
 
 http://www.piemenus.com/
 
 http://www.sm.luth.se/~david/carl/www/argonaut.html
 
 Contact: Jeroen Verbeek, jeroen@happymakinggames.com, Sydney NSW Australia
 */
/*-----------------------------------------------------------------------------------------------*/
#ifndef _INAMEINTERFACE_H_
#define _INAMEINTERFACE_H_


/*-----------------------------------------------------------------------------------------------*/
/*!
\brief	Simple name interface..
 
Use this class to add names to objects. Object name and group name. 
Used by parts such as the menu system. 
 */
/*-----------------------------------------------------------------------------------------------*/
class INameInterface
{
public:

	INameInterface();
	INameInterface(const std::string &strObjectName);
	INameInterface(const std::string &strObjectName, const std::string &strGroupName);
	
	virtual ~INameInterface();

	/*! Set the object name.*/
	inline void SetObjectName(const std::string &strObjectName) { m_strObjectName = strObjectName; }
	/*! Set the group name. */
	inline void SetGroupName(const std::string &strGroupName) { m_strGroupName = strGroupName; }
	
	/*! Get the object name.*/
	const std::string &GetObjectName(void) { return m_strObjectName; }
	/*! Get the group name. */
	const std::string &GetGroupName(void) { return m_strGroupName; }
	
	// Variables -----------------------------------------------

protected:
	std::string m_strObjectName;	//!< String for the object's name.
	std::string m_strGroupName;		//!< String for the object's group name.
};


#endif

//END